<?php
/**
 * Provides a set of default image transforms.
 */

/**
 * implementation of hook_transform_info
 * register transforms
 * transforms array key is basename of callbacks for transform
 */

function transformer_transform_info() {
  $transfors = array();
  $transforms['transformer_crop'] = array(
    'title' => t('Crop'),
    'mimes' => array('image/jpeg','image/gif','image/png'),
    'extensions' => array('gif','jpg','jpeg','png),
  );
  $transforms['transformer_resize'] = array(
    'title' => t('Resize'),
    'mimes' => array('image/jpeg','image/gif','image/png'),
    'extensions' => array('gif','jpg','jpeg','png),
  );
  $transforms['transformer_scale'] = array(
    'title' => t('Scale'),
    'mimes' => array('image/jpeg','image/gif','image/png'),
    'extensions' => array('gif','jpg','jpeg','png),
  );
  $transforms['transformer_fill'] = array(
    'title' => t('Fill'),
    'mimes' => array('image/jpeg','image/gif','image/png'),
    'extensions' => array('gif','jpg','jpeg','png),
  );
  $transforms['transformer_border'] = array(
    'title' => t('Border'),
    'mimes' => array('image/jpeg','image/gif','image/png'),
    'extensions' => array('gif','jpg','jpeg','png),
  );
  return $transforms;
}

/**
 * Crop
 */

function transformer_crop_form($action) {
  $form = array();
  $form['width'] = array(
    '#type' => 'textfield',
    '#size' => 15,'#maxlength' => 30,
    '#title' => t('Width'),
    '#default_value' => $action['data']['width'],
  );
  $form['height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['height'],
  );
  $form['xoffset'] = array(
    '#type' => 'textfield',
    '#title' => t('X Offset'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['xoffset'],
  );
  $form['yoffset'] = array(
    '#type' => 'textfield',
    '#title' => t('Y Offset'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['yoffset'],
  );
  $form['#validate'] = array('transformer_crop_form_validate');
  return $form;
}

function transformer_crop_form_validate() {
}

function transformer_crop_perform($source, $destination, $data) {
  return image_crop($source, $destination, $data['xoffset'] , $data['yoffset'],$data['width'],$data['height']);
}

/**
 * Scale
 */

function transformer_scale_form($action) {
  $form = array();
  $form['width'] = array(
    '#type' => 'textfield',
    '#size' => 15,'#maxlength' => 30,
    '#title' => t('Width'),
    '#default_value' => $action['data']['width'],
  );
  $form['height'] = array(
    '#type' => 'textfield',
    '#size' => 15,'#maxlength' => 30,
    '#title' => t('Height'),
    '#default_value' => $action['data']['height'],
  );
  $form['#validate'] = array('transformer_scale_form_validate');
  return $form;
}

function transformer_scale_form_validate() {
}

function transformer_scale_perform($source, $destination, $data) {
  return image_scale($source, $destination, $data['width'], $data['height']);
}

/**
 * Resize
 */

function transformer_resize_form($action) {
  $form = array();
  $form['width'] = array(
    '#type' => 'textfield',
    '#size' => 15,'#maxlength' => 30,
    '#title' => t('Width'),
    '#default_value' => $action['data']['width'],
  );
  $form['height'] = array(
    '#type' => 'textfield',
    '#size' => 15,'#maxlength' => 30,
    '#title' => t('Height'),
    '#default_value' => $action['data']['height'],
  );
  $form['#validate'] = array('transformer_resize_form_validate');
  return $form;
}

function transformer_resize_form_validate() {
}

function transformer_resize_perform($source, $destination, $data) {
  return image_resize($source, $destination, $data['width'], $data['height']);
}

/**
 * Border
 */

function transformer_border_form($action) {
  $form = array();
  $form['border-color'] = array(
    '#type' => 'textfield',
    '#title' => t('Border color'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['border-color']);

  $form['border-size'] = array(
    '#type' => 'textfield',
    '#title' => t('Border size'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['border-size']);
  $form['#validate'] = array('transformer_border_validat' => array()),
  return $form;
}

function transformer_border_form_validate() {
}

/**
 * Border requires the 'GDmem' toolkit
 *
 */
function transformer_border_perform($source, $destination, $data) {
  _transformer_hex2rgb($data['border-color'],$r,$g,$b);
  return image_toolkit_invoke('border',array($source, $destination, $r, $g, $b, $data['border-size']));
}

/**
 * Fill
 */

function transformer_fill_form($action) {
  $form = array();
  $form['fill_color'] => array(
    '#type' => 'textfield',
    '#title' => t('Fill color'),
    '#size' => 15,'#maxlength' => 30,
    '#default_value' => $action['data']['fill_color'],
  );
  $form['#validate'] = array('transformer_fill_form_validate');
  return $form;
}

function transformer_fill_form_validate() {
}

function transformer_fill_perform($source, $destination, $data) { //*
  _transformer_hex2rgb($data['fill_color'],$r,$g,$b);
  return image_toolkit_invoke('fill', array($source, $destination, $r, $g, $b));
}
?>
